diff --git a/README.md b/README.md
index e615f09..bcff405 100644
--- a/README.md
+++ b/README.md
@@ -155,7 +155,7 @@ You can also access the database cli shell as:
sudo -i # switch to the root user.
systemctl stop nexus # make sure nexus is not running while you use the database.
su -s /bin/bash nexus # switch to the nexus user.
-nexus_home=/opt/nexus/nexus-3.95.3-02 # make sure you have the correct version here.
+nexus_home=/opt/nexus/nexus-3.96.0-09 # make sure you have the correct version here.
nexus_data="$(realpath $nexus_home/../sonatype-work/nexus3)"
install -d $nexus_data/../tmp
rm -f $nexus_data/../tmp/h2-*.jar
diff --git a/provision/provision-nexus/Makefile b/provision/provision-nexus/Makefile
index 96aa2b9..98d79b3 100644
--- a/provision/provision-nexus/Makefile
+++ b/provision/provision-nexus/Makefile
@@ -17,7 +17,7 @@ binaries: binaries-download
binaries-download:
mkdir -p binaries
- wget -qO- https://download.sonatype.com/nexus/3/nexus-3.95.3-02-unix.tar.gz \
+ wget -qO- https://download.sonatype.com/nexus/3/nexus-3.96.0-09-unix.tar.gz \
| tar xzf - --strip-components 1 -C binaries
clean:
diff --git a/provision/provision-nexus/pom.xml b/provision/provision-nexus/pom.xml
index 229d901..7263b8d 100644
--- a/provision/provision-nexus/pom.xml
+++ b/provision/provision-nexus/pom.xml
@@ -8,7 +8,7 @@
1.0-SNAPSHOT
- 3.95.3-02
+ 3.96.0-09
diff --git a/provision/provision-nexus.sh b/provision/provision-nexus.sh
index 0dbedfb..8a2e3ff 100644
--- a/provision/provision-nexus.sh
+++ b/provision/provision-nexus.sh
@@ -35,12 +35,12 @@ pushd /opt/nexus
# see https://help.sonatype.com/en/download-archives---repository-manager-3.html
# see https://help.sonatype.com/en/release-notes.html
# see https://help.sonatype.com/en/sonatype-nexus-repository.html
-nexus_version=3.95.3-02
+nexus_version=3.96.0-09
nexus_home=/opt/nexus/nexus-$nexus_version
nexus_tarball=nexus-$nexus_version-linux-x86_64.tar.gz
nexus_download_url=https://download.sonatype.com/nexus/3/$nexus_tarball
wget -q $nexus_download_url
-tar xf $nexus_tarball # NB this creates the $nexus_home (e.g. nexus-3.95.3-02) and sonatype-work directories.
+tar xf $nexus_tarball # NB this creates the $nexus_home (e.g. nexus-3.96.0-09) and sonatype-work directories.
rm $nexus_tarball
sed -i -E 's,#!.+,#!/usr/bin/bash,g' "$nexus_home/bin/nexus"
install -d -o nexus -g nexus -m 700 .java # java preferences are saved here (the default java.util.prefs.userRoot preference).